==> pyloadl-0.4.3.tar.bz2: pyloadl-0.4.3/examples/llqres.py <==
from pyloadl import *
from time import localtime, strftime
from string import join
from sys import exit

"""

   Displays information on LoadLeveler 
   reservations similar to the llqres command

"""

# Query Job information

query = ll_query(RESERVATIONS)
if not PyCObjValid(query):
   print "ll_query(): returns NULL\n" 
   exit(-1)

retval = ll_set_request(query, QUERY_ALL, "", ALL_DATA)
if retval != 0:
   print "ll_set_request(): error %d\n" % retval
   exit(-1)

res, num, err = ll_get_objs(query, LL_CM, "")
if err != 0:
   print "ll_get_objs(): error %d" % err
   exit(-1)

if num > 0:

   while PyCObjValid(res):

      ID  = ll_get_data(res,  LL_ReservationID)
      print "=============== Reservation %s ===============" % ID

      owner    = ll_get_data(res, LL_ReservationOwner)
      group    = ll_get_data(res, LL_ReservationGroup)
      shared   = ll_get_data(res, LL_ReservationModeShared)
      remove   = ll_get_data(res, LL_ReservationModeRemoveOnIdle)
      status   = ll_get_data(res, LL_ReservationStatus)
      modified = ll_get_data(res, LL_ReservationModifiedBy)
      users    = ll_get_data(res, LL_ReservationUsers)
      groups   = ll_get_data(res, LL_ReservationGroups)
      nodes    = ll_get_data(res, LL_ReservationMachines)
      duration = ll_get_data(res, LL_ReservationDuration)
      jobsteps = ll_get_data(res, LL_ReservationJobs)

      creation = ll_get_data(res, LL_ReservationCreateTime)
      cdate = ""
      if creation != 0:
        creation = localtime(creation)
        cdate  = strftime("%a %d %b %H:%M:%S %Y", creation)

      start = ll_get_data(res, LL_ReservationStartTime)
      sdate = ""
      if start != 0:
        edate = (duration*60) + start
        start = localtime(start)
        sdate  = strftime("%a %d %b %H:%M:%S %Y", start)
        edate = localtime(edate)
        edate  = strftime("%a %d %b %H:%M:%S %Y", edate)

      modifiedT = ll_get_data(res, LL_ReservationModifyTime)
      mdate = ""
      if modifiedT != 0:
        modifiedT = localtime(modifiedT)
        mdate  = strftime("%a %d %b %H:%M:%S %Y", modifiedT)

      print "               ID: %s" % ID
      print "    Creation Time: %s" % cdate
      print "            Owner: %s" % owner
      print "            Group: %s" % group
      print "       Start Time: %s" % sdate
      print "         Duration: %d minutes" % duration
      print "Expected End Time: %s" % edate 
      print "           SHARED: %s" % bool(shared)
      print "   REMOVE_ON_IDLE: %s" % bool(remove)
      print "           Status: %s" % status
      print "      Modified By: %s" % modified
      print "Modification Time: %s" % mdate
      print "            Users: %d" % len(users)
      print "                 : %s" % join(users,',')
      print "           Groups: %d" % len(groups)
      print "                 : %s" % join(groups,',')
      print "            Nodes: %d" % len(nodes)
      print "                 : %s" % join(nodes,',')
      print "        Job Steps: %d" % len(jobsteps)
      print "                 : %s" % join(jobsteps,',')
      print ""

      res = ll_next_obj(query)
else:
     print "llqres: There is currently no reservation status to report"

# Free and deallocate objects used by LoadLeveler

ll_free_objs(query)
ll_deallocate(query)

==> pyloadl-1.0.0-20110612.tar.bz2: pyloadl-1.0.0/examples/llqres.py <==
from pyloadl import *
from time import localtime, strftime
from string import join
from sys import exit

"""

   Displays information on LoadLeveler 
   reservations similar to the llqres command

"""

# Query Job information

query = ll_query(RESERVATIONS)
if not PyCObjValid(query):
   print "ll_query(): returns NULL\n" 
   exit(-1)

retval = ll_set_request(query, QUERY_ALL, "", ALL_DATA)
if retval != 0:
   print "ll_set_request(): error %d\n" % retval
   exit(-1)

res, num, err = ll_get_objs(query, LL_CM, "")
if err != 0:
   print "ll_get_objs(): error %d" % err
   exit(-1)

if num > 0:

   while PyCObjValid(res):

      ID  = ll_get_data(res,  LL_ReservationID)
      print "=============== Reservation %s ===============" % ID

      owner     = ll_get_data(res, LL_ReservationOwner)
      group     = ll_get_data(res, LL_ReservationGroup)
      shared    = ll_get_data(res, LL_ReservationModeShared)
      remove    = ll_get_data(res, LL_ReservationModeRemoveOnIdle)
      status    = ll_get_data(res, LL_ReservationStatus)
      modified  = ll_get_data(res, LL_ReservationModifiedBy)
      users     = ll_get_data(res, LL_ReservationUsers)
      groups    = ll_get_data(res, LL_ReservationGroups)
      nodes     = ll_get_data(res, LL_ReservationMachines)
      duration  = ll_get_data(res, LL_ReservationDuration)
      jobsteps  = ll_get_data(res, LL_ReservationJobs)
      provision = ll_get_data(res, LL_ReservationProvisionFlag)

      creation = ll_get_data(res, LL_ReservationCreateTime)
      cdate = ""
      if creation != 0:
        creation = localtime(creation)
        cdate  = strftime("%a %d %b %H:%M:%S %Y", creation)

      start = ll_get_data(res, LL_ReservationStartTime)
      sdate = ""
      if start != 0:
        edate = (duration*60) + start
        start = localtime(start)
        sdate  = strftime("%a %d %b %H:%M:%S %Y", start)
        edate = localtime(edate)
        edate  = strftime("%a %d %b %H:%M:%S %Y", edate)

      modifiedTime = ll_get_data(res, LL_ReservationModifyTime)
      mdate = ""
      if modifiedTime != 0:
        modifiedTime = localtime(modifiedTime)
        mdate  = strftime("%a %d %b %H:%M:%S %Y", modifiedTime)

      print "               ID: %s" % ID
      print "    Creation Time: %s" % cdate
      print "            Owner: %s" % owner
      print "            Group: %s" % group
      print "       Start Time: %s" % sdate
      print "         Duration: %d minutes" % duration
      print "Expected End Time: %s" % edate 
      print "           SHARED: %s" % bool(shared)
      print "   REMOVE_ON_IDLE: %s" % bool(remove)
      print "        Provision: %s" % bool(provision)
      print "           Status: %s" % status
      print "      Modified By: %s" % modified
      print "Modification Time: %s" % mdate
      print "            Users: %d" % len(users)
      print "                 : %s" % join(users,',')
      print "           Groups: %d" % len(groups)
      print "                 : %s" % join(groups,',')
      print "            Nodes: %d" % len(nodes)
      print "                 : %s" % join(nodes,',')
      print "        Job Steps: %d" % len(jobsteps)
      print "                 : %s" % join(jobsteps,',')
      print ""

      res = ll_next_obj(query)
else:
     print "llqres: There is currently no reservation status to report"

# Free and deallocate objects used by LoadLeveler

ll_free_objs(query)
ll_deallocate(query)
